
// Define all masked image settings supported.
var imagePaths =
[
	"/assets/images/MaskCircleSolid.png",
	"/assets/images/MaskCircleGradient.png",
	"/assets/images/MaskCircleLock.png",
	"/assets/images/MaskCamera.png",
	"/assets/images/MaskHorizontalGradient.png",
	"/assets/images/MaskVerticalGradient.png",
	"/assets/images/AppcLogo.png",
];
var colors =
[
	"red",
	"green",
	"blue",
	"white",
	"rgba(255,0,0,128)",
	"rgba(0,255,0,128)",
	"rgba(0,0,255,128)",
];
var maskSizes =
[
	"'300dp'",
	"Ti.UI.FILL",
	"Ti.UI.SIZE",
];
var blendModes =
[
	"Ti.UI.BLEND_MODE_NORMAL",
	"Ti.UI.BLEND_MODE_MULTIPLY",
	"Ti.UI.BLEND_MODE_SCREEN",
	"Ti.UI.BLEND_MODE_OVERLAY",
	"Ti.UI.BLEND_MODE_DARKEN",
	"Ti.UI.BLEND_MODE_LIGHTEN",
	"Ti.UI.BLEND_MODE_CLEAR",
	"Ti.UI.BLEND_MODE_COPY",
	"Ti.UI.BLEND_MODE_SOURCE_IN",
	"Ti.UI.BLEND_MODE_SOURCE_OUT",
	"Ti.UI.BLEND_MODE_SOURCE_ATOP",
	"Ti.UI.BLEND_MODE_DESTINATION_OVER",
	"Ti.UI.BLEND_MODE_DESTINATION_IN",
	"Ti.UI.BLEND_MODE_DESTINATION_OUT",
	"Ti.UI.BLEND_MODE_DESTINATION_ATOP",
	"Ti.UI.BLEND_MODE_XOR",
	"Ti.UI.BLEND_MODE_PLUS_LIGHTER",
];
if ((Ti.Platform.name === "iOS") || (Ti.Platform.name === "iPhone OS")) {
	// Android does not support these blend modes. They are iOS only.
	blendModes.concat(
	[
		"Ti.UI.BLEND_MODE_COLOR",
		"Ti.UI.BLEND_MODE_COLOR_BURN",
		"Ti.UI.BLEND_MODE_COLOR_DODGE",
		"Ti.UI.BLEND_MODE_DIFFERENCE",
		"Ti.UI.BLEND_MODE_EXCLUSION",
		"Ti.UI.BLEND_MODE_HARD_LIGHT",
		"Ti.UI.BLEND_MODE_HUE",
		"Ti.UI.BLEND_MODE_LUMINOSITY",
		"Ti.UI.BLEND_MODE_PLUS_DARKER",
		"Ti.UI.BLEND_MODE_SATURATION",
		"Ti.UI.BLEND_MODE_SOFT_LIGHT",
	]);
}
blendModes.sort();

// Creates a nice short name from given image file path. Intended to be displayed onscreen.
function getNameFromImagePath(path) {
	if (path) {
		path = path.replace("/assets/images/", "");
	} else {
		path = "";
	}
	return path;
}

// Creates a nice short name from given BLEND_MODE constant number or string. Intended to be displayed onscreen.
function getNameFromBlendMode(mode) {
	if (Number.isInteger(mode)) {
		mode = blendModes.find(function(item) { return eval(item) === mode; });
	}
	if (mode) {
		mode = mode.toString().replace("Ti.UI.BLEND_MODE_", "");
	} else {
		mode = "";
	}
	return mode;
}

// Set up the window.
var window = Ti.UI.createWindow(
{
	fullscreen: true,
	layout: "vertical",
});

// Set up the masked image and its container.
var maskContainer = Ti.UI.createView(
{
	backgroundColor: "white",
	width: Ti.UI.FILL,
	height: "50%",
});
var maskedImage = Ti.UI.createMaskedImage(
{
	mask: imagePaths[0],
	image: imagePaths[6],
	width: eval(maskSizes[0]),
	height: eval(maskSizes[0]),
//backgroundColor: "green",
//borderColor: "black", borderWidth: "1dp",
//tintColor: "blue",
//opacity: 0.5,
});
maskContainer.add(maskedImage);
window.add(maskContainer);

// Show a line between masked image and the UI controls. 
window.add(Ti.UI.createView(
{
	backgroundColor: "gray",
	width: Ti.UI.FILL,
	height: "1dp",
}));

// Create a view used to contain all UI controls that will manipulate the image.
var uiContainer = Ti.UI.createView(
{
	layout: "horizontal",
	width: Ti.UI.FILL,
	height: Ti.UI.SIZE,
});

// Set up the "mask" configuration controls.
uiContainer.add(Ti.UI.createLabel({ text: "Mask: ", left: "5dp", width: "30%" }));
var maskButton = Ti.UI.createButton(
{
	title: getNameFromImagePath(maskedImage.mask || "None"),
	width: Ti.UI.FILL,
});
maskButton.addEventListener("click", function(e) {
	var dialog = Ti.UI.createOptionDialog({
		title: "Select Mask",
		options: imagePaths.concat(["None"]).map(getNameFromImagePath),
	});
	dialog.addEventListener("click", function(e) {
		if (e.index >= 0) {
			maskedImage.mask = (e.index < imagePaths.length) ? imagePaths[e.index] : null;
			maskButton.title = dialog.options[e.index];
		}
	});
	dialog.show();
});
uiContainer.add(maskButton);

// Set up the "image" configuration controls.
uiContainer.add(Ti.UI.createLabel({ text: "Image: ", left: "5dp", width: "30%" }));
var imageButton = Ti.UI.createButton(
{
	title: getNameFromImagePath(maskedImage.image || "None"),
	width: Ti.UI.FILL,
});
imageButton.addEventListener("click", function(e) {
	var dialog = Ti.UI.createOptionDialog({
		title: "Select Image",
		options: imagePaths.concat(["None"]).map(getNameFromImagePath),
	});
	dialog.addEventListener("click", function(e) {
		if (e.index >= 0) {
			maskedImage.image = (e.index < imagePaths.length) ? imagePaths[e.index] : null;
			imageButton.title = dialog.options[e.index];
		}
	});
	dialog.show();
});
uiContainer.add(imageButton);

// Set up the "tint" color configuration controls.
uiContainer.add(Ti.UI.createLabel({ text: "Tint: ", left: "5dp", width: "30%" }));
var tintButton = Ti.UI.createButton(
{
	title: maskedImage.tint || "None",
	width: Ti.UI.FILL,
});
tintButton.addEventListener("click", function(e) {
	var dialog = Ti.UI.createOptionDialog({
		title: "Select Tint Color",
		options: colors.concat(["None"]),
	});
	dialog.addEventListener("click", function(e) {
		if (e.index >= 0) {
			maskedImage.tint = (e.index < colors.length) ? colors[e.index] : null;
			tintButton.title = dialog.options[e.index];
		}
	});
	dialog.show();
});
uiContainer.add(tintButton);

// Set up the mask's blend "mode" configuration controls.
uiContainer.add(Ti.UI.createLabel({ text: "Mode: ", left: "5dp", width: "30%" }));
var modeButton = Ti.UI.createButton(
{
	title: getNameFromBlendMode(blendModes.find(function(item) { return eval(item) === maskedImage.mode; })),
	width: Ti.UI.FILL,
});
modeButton.addEventListener("click", function(e) {
	var dialog = Ti.UI.createOptionDialog({
		title: "Select Blend Mode",
		options: blendModes.map(getNameFromBlendMode),
	});
	dialog.addEventListener("click", function(e) {
		if (e.index >= 0) {
			modeButton.title = dialog.options[e.index];
			maskedImage.mode = eval(blendModes[e.index]);
		}
	});
	dialog.show();
});
uiContainer.add(modeButton);

// Set up the masked image sizing controls.
uiContainer.add(Ti.UI.createLabel({ text: "Size: ", left: "5dp", width: "30%" }));
var sizeButton = Ti.UI.createButton(
{
	title: maskSizes.find(function(item) { return eval(item) === maskedImage.width; }),
	width: Ti.UI.FILL,
});
sizeButton.addEventListener("click", function(e) {
	var dialog = Ti.UI.createOptionDialog({
		title: "Select Size",
		options: maskSizes,
	});
	dialog.addEventListener("click", function(e) {
		if (e.index >= 0) {
			sizeButton.title = dialog.options[e.index];
			maskedImage.width = eval(sizeButton.title);
			maskedImage.height = maskedImage.width;
		}
	});
	dialog.show();
});
uiContainer.add(sizeButton);

// Set up the background color configuration controls.
uiContainer.add(Ti.UI.createLabel({ text: "Background: ", left: "5dp", width: "30%" }));
var backgroundButton = Ti.UI.createButton(
{
	title: maskContainer.backgroundColor || "transparent",
	width: Ti.UI.FILL,
});
backgroundButton.addEventListener("click", function(e) {
	var dialog = Ti.UI.createOptionDialog({
		title: "Select Background Color",
		options: colors.concat(["transparent"]),
	});
	dialog.addEventListener("click", function(e) {
		if (e.index >= 0) {
			backgroundButton.title = dialog.options[e.index];
			maskContainer.backgroundColor = backgroundButton.title;
		}
	});
	dialog.show();
});
uiContainer.add(backgroundButton);

// Add all UI controls to a vertical ScrollView.
// This way all UI is reachable when put into landscape mode.
var uiScrollView = Ti.UI.createScrollView(
{
	layout: "vertical",
	scrollType: "vertical",
	showHorizontalScrollIndicator: false,
	shorVerticalScrollIndicator: true,
	width: Ti.UI.FILL,
	height: Ti.UI.FILL,
});
uiScrollView.add(uiContainer);
window.add(uiScrollView);

// Display the app window.
window.open();

